accuracy_plot: accuracy plot function takes in a tibble with mean of...

View source: R/accuracy_plot.R

accuracy_plotR Documentation

accuracy plot function takes in a tibble with mean of accuracy and neighbours and plots it

Description

accuracy plot function takes in a tibble with mean of accuracy and neighbours and plots it

Usage

accuracy_plot(tibble)

Arguments

accuracies

a tibble that contains accuracy estimates at different numbers of neighbours

Value

a plot that indicates accuracy estimates at different value of neighbours

Examples

accuracy_plot(accuracy)

DSCI-310/DSCI-310-Group-2-packages documentation built on April 19, 2022, 11:14 a.m.