clean_data: Cleans dataframe

View source: R/clean_data.R

clean_dataR Documentation

Cleans dataframe

Description

Finds all instances of missing data and converts it to NA Then removes all rows with NA to create a new dataframe, this dataframe must only have museric types

Usage

clean_data(df)

Arguments

df

A dataframe or dataframe extension

Value

A dataframe with only numeric data with no missing values

Examples

clean_data(heart_disease)

DSCI-310/DSCI-310-Group-2-packages documentation built on April 19, 2022, 11:14 a.m.