View source: R/accuracy_plot.R
| accuracy_plot | R Documentation |
accuracy plot function takes in a tibble with mean of accuracy and neighbours and plots it
accuracy_plot(tibble)
accuracies |
a tibble that contains accuracy estimates at different numbers of neighbours |
a plot that indicates accuracy estimates at different value of neighbours
accuracy_plot(accuracy)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.