| clean_data | R Documentation |
Finds all instances of missing data and converts it to NA Then removes all rows with NA to create a new dataframe, this dataframe must only have museric types
clean_data(df)
df |
A dataframe or dataframe extension |
A dataframe with only numeric data with no missing values
clean_data(heart_disease)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.